<?php

/**
 * Theme Customizer - Presets
 *
 * @package Selleradise
 */

namespace Selleradise\Api\Customizer;

use Kirki;
use Selleradise\Api\Customizer;

/**
 * Customizer class
 */
class Shop
{
    /**
     * register default hooks and actions for WordPress
     * @return
     */
    public function register()
    {

        if (!class_exists('Kirki') || !class_exists('WooCommerce')) {
            return;
        }

        if (!is_customize_preview()) {
            return;
        }

        Kirki::add_field('selleradise', [
            'type' => 'radio',
            'settings' => 'filters_location',
            'label' => __('Shop Filter Location', 'selleradise'),
            'description' => esc_html__('Where to show the filters for the product catalog?', 'selleradise'),
            'section' => 'woocommerce_product_catalog',
            'default' => 'sidebar',
            'priority' => 30,
            'choices' => [
                'sidebar' => esc_html__('Right Sidebar', 'selleradise'),
                'offscreen' => esc_html__('Off Screen', 'selleradise'),
                'sidebar-left' => esc_html__('Left Sidebar', 'selleradise'),
            ],
            'transport' => 'refresh',
        ]);

        // <REMOVE_IN_LITE>

        Kirki::add_field('selleradise', [
            'type' => 'radio',
            'settings' => 'shop_page_card_type',
            'label' => __('Product Card Type', 'selleradise'),
            'description' => esc_html__('Which type of card design should be used for the shop?', 'selleradise'),
            'section' => 'woocommerce_product_catalog',
            'default' => 'default',
            'priority' => 40,
            'choices' => [
                'default' => esc_html__('Default', 'selleradise'),
                'minimal' => esc_html__('Minimal', 'selleradise'),
                'simple' => esc_html__('Simple', 'selleradise'),
                'list' => esc_html__('List', 'selleradise'),
                'compact' => esc_html__('Compact', 'selleradise'),
                'rounded' => esc_html__('Rounded', 'selleradise'),
            ],
            'transport' => 'refresh',
        ]);
        
        // </REMOVE_IN_LITE>

        Kirki::add_field('selleradise', [
            'type' => 'multicheck',
            'settings' => 'shop_filters_to_show',
            'label' => __('Filters To Show', 'selleradise'),
            'description' => esc_html__('Which filters should be visible in the sidebar?', 'selleradise'),
            'section' => 'woocommerce_product_catalog',
            'default'  => [ 'price', 'categories', 'attributes', 'tags' ],
            'priority' => 50,
            'choices' => [
                'price' => esc_html__('Price', 'selleradise'),
                'categories' => esc_html__('Categories', 'selleradise'),
                'attributes' => esc_html__('Attributes', 'selleradise'),
                'tags' => esc_html__('Tags', 'selleradise'),
            ],
            'transport' => 'refresh',
        ]);

        Kirki::add_field('selleradise', [
            'type' => 'checkbox',
            'settings' => 'shop_filters_submit_on_change',
            'label' => __('Submit Filters Form On Change', 'selleradise'),
            'section' => 'woocommerce_product_catalog',
            'default' => false,
            'priority' => 60,
            'transport' => 'refresh',
        ]);

    }
}
